==> iw.email-0.1.tar.gz: iw.email-0.1/setup.py <==
# -*- coding: utf-8 -*-
# Copyright (C)2007 'Ingeniweb'

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING. If not, write to the
# Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""
This module contains the tool of iw.email
"""
import os
from setuptools import setup, find_packages

version = '0.1'

README = os.path.join(os.path.dirname(__file__),
          'iw',
          'email', 'docs', 'README.txt')

long_description = open(README).read() + '\n\n'

setup(name='iw.email',
      version=version,
      description="Email utilities",
      long_description=long_description,
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        ],
      keywords='',
      author='Ingeniweb',
      author_email='support@ingeniweb.com',
      url='',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['iw'],
      include_package_data=True,
      zip_safe=False,
      test_suite = "iw.email.tests.test_emaildocs.test_suite",
      install_requires=[
          'setuptools',
          'docutils',
          'Cheetah',
          'zope.testing',
          'zope.component',
          'zope.interface',
          # we need zope.pagetemplate but egg seems broken..
          #'zope.pagetemplate',
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      )

==> iw.email-0.3.tar.gz: iw.email-0.3/setup.py <==
# -*- coding: utf-8 -*-
# Copyright (C)2007 'Ingeniweb'

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING. If not, write to the
# Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""
This module contains the tool of iw.email
"""
import os
from setuptools import setup, find_packages

version = '0.3'

package_dir = os.path.join(os.path.dirname(__file__), 'iw','email')

READMES = [os.path.join(package_dir, 'docs', 'README.txt'),
           os.path.join(package_dir, 'doctests', 'README.txt'),
           os.path.join(package_dir, 'docs', 'testing.txt')]

long_description = ''
for filename in READMES:
    long_description += open(filename).read() + '\n\n'

tests_require = [
        'zope.testing',
        'zope.component',
    ]

setup(name='iw.email',
      version=version,
      description="Email utilities",
      long_description=long_description,
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        ],
      keywords='',
      author='Ingeniweb',
      author_email='support@ingeniweb.com',
      url='',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['iw'],
      include_package_data=True,
      zip_safe=False,
      test_suite = "iw.email.tests.test_emaildocs.test_suite",
      tests_require=tests_require,
      extras_require=dict(test=tests_require),
      install_requires=[
          'setuptools',
          'docutils',
          'Cheetah',
          # eggs needed but break zope2 buildout..
          #'zope.component',
          #'zope.interface',
          # we need zope.pagetemplate but egg seems broken..
          #'zope.pagetemplate',
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      )
